@@ -5,7 +5,7 @@ use serde::{Deserialize, Serialize};
 use crate::rules::{
     at_rule_no_unknown::AtRuleNoUnknownConfig, color_hex_length::ColorHexLengthConfig,
     no_invalid_position_at_import_rule::NoInvalidPositionAtImportRuleConfig,
-    unit_no_unknown::UnitNoUnknownConfig,
+    selector_max_class::SelectorMaxClassConfig, unit_no_unknown::UnitNoUnknownConfig,
 };
 
 #[derive(Debug, Clone, Copy, Serialize, Deserialize)]
@@ -64,10 +64,6 @@ impl<T: Debug + Clone + Serialize + Default> RuleConfig<T> {
     pub(crate) fn get_rule_config(&self) -> &T {
         &self.1
     }
-
-    pub(crate) fn is_enabled(&self) -> bool {
-        !matches!(self.get_rule_reaction(), LintRuleReaction::Off)
-    }
 }
 
 #[derive(Debug, Clone, Default, Serialize, Deserialize)]
@@ -93,7 +89,7 @@ pub struct RulesConfig {
     pub no_invalid_position_at_import_rule: RuleConfig<NoInvalidPositionAtImportRuleConfig>,
 
     #[serde(default, alias = "selectorMaxClass")]
-    pub selector_max_class: RuleConfig<Option<usize>>,
+    pub selector_max_class: RuleConfig<SelectorMaxClassConfig>,
 
     #[serde(default, alias = "colorHexLength")]
     pub color_hex_length: RuleConfig<ColorHexLengthConfig>,
