@@ -1,15 +1,12 @@
-use swc_common::{errors::HANDLER, Span};
+use swc_common::Span;
 use swc_css_ast::*;
 use swc_css_visit::{Visit, VisitWith};
 
-use crate::{
-    config::{LintRuleReaction, RuleConfig},
-    rule::{visitor_rule, LintRule},
-};
+use crate::rule::{visitor_rule, LintRule, LintRuleContext};
 
-pub fn declaration_no_important(config: &RuleConfig<()>) -> Box<dyn LintRule> {
+pub fn declaration_no_important(ctx: LintRuleContext<()>) -> Box<dyn LintRule> {
     visitor_rule(DeclarationNoImportant {
-        reaction: config.get_rule_reaction(),
+        ctx,
         keyframe_rules: vec![],
     })
 }
@@ -18,7 +15,7 @@ const MESSAGE: &str = "Unexpected '!important'.";
 
 #[derive(Debug, Default)]
 struct DeclarationNoImportant {
-    reaction: LintRuleReaction,
+    ctx: LintRuleContext<()>,
 
     // rule interal
     keyframe_rules: Vec<Span>,
@@ -38,17 +35,7 @@ impl Visit for DeclarationNoImportant {
             Some(span) if span.contains(important_flag.span) => {
                 // This rule doesn't check `!important` flag inside `@keyframe`.
             }
-            _ => {
-                HANDLER.with(|handler| match self.reaction {
-                    LintRuleReaction::Error => {
-                        handler.struct_span_err(important_flag.span, MESSAGE).emit()
-                    }
-                    LintRuleReaction::Warning => handler
-                        .struct_span_warn(important_flag.span, MESSAGE)
-                        .emit(),
-                    _ => {}
-                });
-            }
+            _ => self.ctx.report(important_flag, MESSAGE),
         }
 
         important_flag.visit_children_with(self);
