@@ -1,12 +1,8 @@
 use serde::{Deserialize, Serialize};
-use swc_common::{errors::HANDLER, Spanned};
 use swc_css_ast::*;
 use swc_css_visit::{Visit, VisitWith};
 
-use crate::{
-    config::{LintRuleReaction, RuleConfig},
-    rule::{visitor_rule, LintRule},
-};
+use crate::rule::{visitor_rule, LintRule, LintRuleContext};
 
 const MESSAGE: &str = "Unexpected invalid position '@import' rule.";
 
@@ -17,21 +13,15 @@ pub struct NoInvalidPositionAtImportRuleConfig {
 }
 
 pub fn no_invalid_position_at_import_rule(
-    config: &RuleConfig<NoInvalidPositionAtImportRuleConfig>,
+    ctx: LintRuleContext<NoInvalidPositionAtImportRuleConfig>,
 ) -> Box<dyn LintRule> {
-    visitor_rule(NoInvalidPositionAtImportRule {
-        reaction: config.get_rule_reaction(),
-        ignored: config
-            .get_rule_config()
-            .ignore_at_rules
-            .clone()
-            .unwrap_or_default(),
-    })
+    let ignored = ctx.config().ignore_at_rules.clone().unwrap_or_default();
+    visitor_rule(NoInvalidPositionAtImportRule { ctx, ignored })
 }
 
 #[derive(Debug, Default)]
 struct NoInvalidPositionAtImportRule {
-    reaction: LintRuleReaction,
+    ctx: LintRuleContext<NoInvalidPositionAtImportRuleConfig>,
     ignored: Vec<String>,
 }
 
@@ -39,13 +29,7 @@ impl Visit for NoInvalidPositionAtImportRule {
     fn visit_stylesheet(&mut self, stylesheet: &Stylesheet) {
         stylesheet.rules.iter().fold(false, |seen, rule| {
             if seen && matches!(rule, Rule::AtRule(AtRule::Import(..))) {
-                HANDLER.with(|handler| match self.reaction {
-                    LintRuleReaction::Error => handler.struct_span_err(rule.span(), MESSAGE).emit(),
-                    LintRuleReaction::Warning => {
-                        handler.struct_span_warn(rule.span(), MESSAGE).emit()
-                    }
-                    _ => {}
-                });
+                self.ctx.report(rule, MESSAGE);
             }
 
             match rule {
